@@ -19,9 +19,12 @@
  */
 
 #include "dialog_field_layout.h"
-#include "../data_structure/glomconversions.h"
+#include <glom/libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Dialog_FieldLayout::Dialog_FieldLayout(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Dialog(cobject),
   m_label_field_name(0),
@@ -129,4 +132,6 @@ void Dialog_FieldLayout::enforce_constraints()
   m_box_formatting->set_sensitive(custom);
 }
 
+} //namespace Glom
+
 
