@@ -22,10 +22,13 @@
 #define GLOM_TRANSLATIONS_DIALOG_COPY_TRANSLATION_H
 
 #include "combobox_locale.h"
-#include "../document/document_glom.h" // For View_Composite_Glom
+#include <glom/libglom/document/document_glom.h> // For View_Composite_Glom
 #include <libglademm.h>
 #include <gtkmm/dialog.h>
 
+namespace Glom
+{
+
 /**
  */
 class Dialog_CopyTranslation
@@ -41,5 +44,7 @@ protected:
   ComboBox_Locale* m_combo_locale;
 };
 
+} //namespace Glom
+
 #endif //GLOM_TRANSLATIONS_DIALOG_COPY_TRANSLATION_H
 
