@@ -22,10 +22,13 @@
 #define GLOM_UTILITY_WIDGETS_TEXTVIEW_GLOM_H
 
 #include <gtkmm.h>
-#include "../data_structure/field.h"
+#include <glom/libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
 #include <libglademm.h>
 
+namespace Glom
+{
+
 class App_Glom;
 
 class TextViewGlom
@@ -71,5 +74,7 @@ protected:
   Gtk::TextView m_TextView;
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITY_WIDGETS_TEXTVIEW_GLOM_H
 
